{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "LLL",
    MEd => "E, d. MMM",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d. MMM",
    Md => "d. MMM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d. MMM y",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "wae-CH",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+00e4}n",
    "Zi\N{U+0161}",
    "Mit",
    "Fr\N{U+00f3}",
    "Fri",
    "Sam",
    "Sun",
  ],
  day_format_narrow => [
    "M",
    "Z",
    "M",
    "F",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "M\N{U+00e4}ntag",
    "Zi\N{U+0161}tag",
    "Mittwu\N{U+010d}",
    "Fr\N{U+00f3}ntag",
    "Fritag",
    "Sam\N{U+0161}tag",
    "Sunntag",
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+00e4}n",
    "Zi\N{U+0161}",
    "Mit",
    "Fr\N{U+00f3}",
    "Fri",
    "Sam",
    "Sun",
  ],
  day_stand_alone_narrow => [
    "M",
    "Z",
    "M",
    "F",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "M\N{U+00e4}ntag",
    "Zi\N{U+0161}tag",
    "Mittwu\N{U+010d}",
    "Fr\N{U+00f3}ntag",
    "Fritag",
    "Sam\N{U+0161}tag",
    "Sunntag",
  ],
  era_abbreviated => [
    "v. Chr.",
    "n. Chr",
  ],
  era_narrow => [
    "v. Chr.",
    "n. Chr",
  ],
  era_wide => [
    "v. Chr.",
    "n. Chr",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %-d %b %H:%M:%S %Z %Y",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%a %d. %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Walser",
  month_format_abbreviated => [
    "Jen",
    "Hor",
    "M\N{U+00e4}r",
    "Abr",
    "Mei",
    "Br\N{U+00e1}",
    "Hei",
    "\N{U+00d6}ig",
    "Her",
    "W\N{U+00ed}m",
    "Win",
    "Chr",
  ],
  month_format_narrow => [
    "J",
    "H",
    "M",
    "A",
    "M",
    "B",
    "H",
    "\N{U+00d6}",
    "H",
    "W",
    "W",
    "C",
  ],
  month_format_wide => [
    "Jenner",
    "Hornig",
    "M\N{U+00e4}rze",
    "Abrille",
    "Meije",
    "Br\N{U+00e1}\N{U+010d}et",
    "Heiwet",
    "\N{U+00d6}ig\N{U+0161}te",
    "Herb\N{U+0161}tm\N{U+00e1}net",
    "W\N{U+00ed}m\N{U+00e1}net",
    "Winterm\N{U+00e1}net",
    "Chri\N{U+0161}tm\N{U+00e1}net",
  ],
  month_stand_alone_abbreviated => [
    "Jen",
    "Hor",
    "M\N{U+00e4}r",
    "Abr",
    "Mei",
    "Br\N{U+00e1}",
    "Hei",
    "\N{U+00d6}ig",
    "Her",
    "W\N{U+00ed}m",
    "Win",
    "Chr",
  ],
  month_stand_alone_narrow => [
    "J",
    "H",
    "M",
    "A",
    "M",
    "B",
    "H",
    "\N{U+00d6}",
    "H",
    "W",
    "W",
    "C",
  ],
  month_stand_alone_wide => [
    "Jenner",
    "Hornig",
    "M\N{U+00e4}rze",
    "Abrille",
    "Meije",
    "Br\N{U+00e1}\N{U+010d}et",
    "Heiwet",
    "\N{U+00d6}ig\N{U+0161}te",
    "Herb\N{U+0161}tm\N{U+00e1}net",
    "W\N{U+00ed}m\N{U+00e1}net",
    "Winterm\N{U+00e1}net",
    "Chri\N{U+0161}tm\N{U+00e1}net",
  ],
  name => "Walser Switzerland",
  native_language => "Walser",
  native_name => "Walser Schwiz",
  native_script => undef,
  native_territory => "Schwiz",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. quartal",
    "2. quartal",
    "3. quartal",
    "4. quartal",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. quartal",
    "2. quartal",
    "3. quartal",
    "4. quartal",
  ],
  script => undef,
  territory => "Switzerland",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
