{
  am_pm_abbreviated => [
    "Sub",
    "Ngo",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM, y G",
    GyMMMEd => "E, d MMM, y G",
    GyMMMd => "d MMM, y G",
    GyMd => "dd-MM-y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd-MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd-MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM-y",
    yMEd => "E, dd-MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd-MM-y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "wo-SN",
  date_format_full => "EEEE, d MMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "dd-MM-y",
  datetime_format_full => "{1} 'ci' {0}",
  datetime_format_long => "{1} 'ci' {0}",
  datetime_format_medium => "{1} - {0}",
  datetime_format_short => "{1} - {0}",
  day_format_abbreviated => [
    "Alt",
    "Tal",
    "\N{U+00c0}la",
    "Alx",
    "\N{U+00c0}jj",
    "Ase",
    "Dib",
  ],
  day_format_narrow => [
    "Alt",
    "Tal",
    "\N{U+00c0}la",
    "Alx",
    "\N{U+00c0}jj",
    "Ase",
    "Dib",
  ],
  day_format_wide => [
    "Altine",
    "Talaata",
    "\N{U+00c0}larba",
    "Alxamis",
    "\N{U+00c0}jjuma",
    "Aseer",
    "Dib\N{U+00e9}er",
  ],
  day_stand_alone_abbreviated => [
    "Alt",
    "Tal",
    "\N{U+00c0}la",
    "Alx",
    "\N{U+00c0}jj",
    "Ase",
    "Dib",
  ],
  day_stand_alone_narrow => [
    "Alt",
    "Tal",
    "\N{U+00c0}la",
    "Alx",
    "\N{U+00c0}jj",
    "Ase",
    "Dib",
  ],
  day_stand_alone_wide => [
    "Altine",
    "Talaata",
    "\N{U+00c0}larba",
    "Alxamis",
    "\N{U+00c0}jjuma",
    "Aseer",
    "Dib\N{U+00e9}er",
  ],
  era_abbreviated => [
    "JC",
    "AD",
  ],
  era_narrow => [
    "JC",
    "AD",
  ],
  era_wide => [
    "av. JC",
    "AD",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Wolof",
  month_format_abbreviated => [
    "Sam",
    "Few",
    "Mar",
    "Awr",
    "Mee",
    "Suw",
    "Sul",
    "Ut",
    "S\N{U+00e0}t",
    "Okt",
    "Now",
    "Des",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Samwiyee",
    "Fewriyee",
    "Mars",
    "Awril",
    "Mee",
    "Suwe",
    "Sulet",
    "Ut",
    "S\N{U+00e0}ttumbar",
    "Oktoobar",
    "Now\N{U+00e0}mbar",
    "Des\N{U+00e0}mbar",
  ],
  month_stand_alone_abbreviated => [
    "Sam",
    "Few",
    "Mar",
    "Awr",
    "Mee",
    "Suw",
    "Sul",
    "Ut",
    "S\N{U+00e0}t",
    "Okt",
    "Now",
    "Des",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Samwiyee",
    "Fewriyee",
    "Mars",
    "Awril",
    "Mee",
    "Suwe",
    "Sulet",
    "Ut",
    "S\N{U+00e0}ttumbar",
    "Oktoobar",
    "Now\N{U+00e0}mbar",
    "Des\N{U+00e0}mbar",
  ],
  name => "Wolof Senegal",
  native_language => "Wolof",
  native_name => "Wolof Senegaal",
  native_script => undef,
  native_territory => "Senegaal",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1er Tri",
    "2e Tri",
    "3e Tri",
    "4e Tri",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1er Trimestar",
    "2e Trimestar",
    "3e Trimestar",
    "4e Trimestar",
  ],
  quarter_stand_alone_abbreviated => [
    "1er Tri",
    "2e Tri",
    "3e Tri",
    "4e Tri",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1er Trimestar",
    "2e Trimestar",
    "3e Trimestar",
    "4e Trimestar",
  ],
  script => undef,
  territory => "Senegal",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
