{
  am_pm_abbreviated => [
    "Z.MU.",
    "Z.MW.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "rn-BI",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "mbe.",
    "kab.",
    "gtu.",
    "kan.",
    "gnu.",
    "gnd.",
    "cu.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Ku wa mbere",
    "Ku wa kabiri",
    "Ku wa gatatu",
    "Ku wa kane",
    "Ku wa gatanu",
    "Ku wa gatandatu",
    "Ku w\N{U+2019}indwi",
  ],
  day_stand_alone_abbreviated => [
    "mbe.",
    "kab.",
    "gtu.",
    "kan.",
    "gnu.",
    "gnd.",
    "cu.",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Ku wa mbere",
    "Ku wa kabiri",
    "Ku wa gatatu",
    "Ku wa kane",
    "Ku wa gatanu",
    "Ku wa gatandatu",
    "Ku w\N{U+2019}indwi",
  ],
  era_abbreviated => [
    "Mb.Y.",
    "Ny.Y",
  ],
  era_narrow => [
    "Mb.Y.",
    "Ny.Y",
  ],
  era_wide => [
    "Mbere ya Yezu",
    "Nyuma ya Yezu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Rundi",
  month_format_abbreviated => [
    "Mut.",
    "Gas.",
    "Wer.",
    "Mat.",
    "Gic.",
    "Kam.",
    "Nya.",
    "Kan.",
    "Nze.",
    "Ukw.",
    "Ugu.",
    "Uku.",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Nzero",
    "Ruhuhuma",
    "Ntwarante",
    "Ndamukiza",
    "Rusama",
    "Ruheshi",
    "Mukakaro",
    "Nyandagaro",
    "Nyakanga",
    "Gitugutu",
    "Munyonyo",
    "Kigarama",
  ],
  month_stand_alone_abbreviated => [
    "Mut.",
    "Gas.",
    "Wer.",
    "Mat.",
    "Gic.",
    "Kam.",
    "Nya.",
    "Kan.",
    "Nze.",
    "Ukw.",
    "Ugu.",
    "Uku.",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Nzero",
    "Ruhuhuma",
    "Ntwarante",
    "Ndamukiza",
    "Rusama",
    "Ruheshi",
    "Mukakaro",
    "Nyandagaro",
    "Nyakanga",
    "Gitugutu",
    "Munyonyo",
    "Kigarama",
  ],
  name => "Rundi Burundi",
  native_language => "Ikirundi",
  native_name => "Ikirundi Uburundi",
  native_script => undef,
  native_territory => "Uburundi",
  native_variant => undef,
  quarter_format_abbreviated => [
    "I1",
    "I2",
    "I3",
    "I4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Igice ca mbere c\N{U+2019}umwaka",
    "Igice ca kabiri c\N{U+2019}umwaka",
    "Igice ca gatatu c\N{U+2019}umwaka",
    "Igice ca kane c\N{U+2019}umwaka",
  ],
  quarter_stand_alone_abbreviated => [
    "I1",
    "I2",
    "I3",
    "I4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Igice ca mbere c\N{U+2019}umwaka",
    "Igice ca kabiri c\N{U+2019}umwaka",
    "Igice ca gatatu c\N{U+2019}umwaka",
    "Igice ca kane c\N{U+2019}umwaka",
  ],
  script => undef,
  territory => "Burundi",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
